@@ -184,6 +184,14 @@ impl Editor {
                             }
 
                         }
+                        // Navigation
+                        Key::Char('k') => self.move_cursor(Key::Up),
+                        Key::Char('j') => self.move_cursor(Key::Down),
+                        Key::Char('l') => self.move_cursor(Key::Right),
+                        Key::Char('h') => self.move_cursor(Key::Left),
+                        Key::Char('H') => {
+                            self.cursor_position.y = 0;
+                        }
                         _ => (),
                     }
                 } else {
@@ -326,14 +334,14 @@ impl Editor {
                 .document
                 .row(self.offset.y.saturating_add(terminal_row as usize))
             {
+                Terminal::set_fg_color(Rgb(249, 241, 165));
+                print!("{} ", self.offset.y.saturating_add(terminal_row as usize));
+                Terminal::reset_fg_color();
                 self.draw_row(row);
 
             } else if self.document.is_empty() && terminal_row == height / 3 && self.just_entered {
                 self.draw_welcome_message();
             } else {
-                Terminal::set_fg_color(color::Rgb(59, 120, 255));
-                println!("~\r");
-                Terminal::reset_fg_color();
             }
         }
     }
